@@ -1,3 +1,5 @@
+import os
+
 from python_grains.profiles.profiles import Profile
 from python_grains.profiles.profile_properties import (PROFILE_VALUE_CREATED_POSTFIX,
                                                        PROFILE_VALUE_UPDATED_POSTFIX,
@@ -74,6 +76,21 @@ def attach_profile_lua_scripts(redis_client,
                 expire_postfix=PROFILE_VALUE_EXPIRE_AT_POSTFIX
             ))
 
+    if not hasattr(redis_client, 'finalize_profile'):
+
+        redis_client.finalize_profile = redis_client.register_script(
+            LuaScripts.finalize_profile(local=bool(os.getenv('DJANGO_DEVELOPMENT'))))
+
+    if not hasattr(redis_client, 'delete_in_cache'):
+
+        redis_client.delete_in_cache = redis_client.register_script(
+            LuaScripts.delete_in_cache())
+
+    if not hasattr(redis_client, 'get_all_user_pointers_if_main_profile'):
+
+        redis_client.get_all_user_pointers_if_main_profile = redis_client.register_script(
+            LuaScripts.get_all_user_pointers_if_main_profile())
+
     return redis_client
 
 def getProfileClass(
@@ -81,6 +98,8 @@ def getProfileClass(
         fast_clean_threshold,
         redis_client,
         django_profile_model,
+        django_pointer_model,
+        django_count_func,
         profile_ttl,
         profile_ttl_margin,
         user_ttl,
@@ -98,6 +117,8 @@ def getProfileClass(
                                                   profile_ttl_margin=profile_ttl_margin,
                                                   new_user_detection_ttl=new_user_detection_ttl)
     cls.django_profile_model = django_profile_model
+    cls.django_pointer_model = django_pointer_model
+    cls.django_count_func = django_count_func
     cls.profile_ttl = profile_ttl
     cls.profile_ttl_margin = profile_ttl_margin
     cls.user_ttl = user_ttl
