@@ -1,3 +1,5 @@
+import os
+
 class LuaScripts(object):
 
     @classmethod
@@ -483,5 +485,101 @@ class LuaScripts(object):
 
                 end
 
+                return result
+            '''
+
+    @classmethod
+    def switch_profiles(cls,
+                        user_ttl,
+                        user_ttl_margin):
+        '''
+        Make sure you place the new profile in the database first
+        KEYS[1]: profile pool key
+        KEYS[2]: all profile keys key
+        ARGV[1]: json array of old profile_keys
+        ARGV[2]: new_profile_key
+        '''
+
+        return '''
+            local old_profile_keys = cjson.decode(ARGV[1])
+            redis.call('ZREM', KEYS[2], unpack(old_profile_keys))
+            redis.call('DEL', unpack(old_profile_keys))
+
+            local pool_exists = (redis.call('EXISTS', KEYS[1]) == 1)
+
+            if pool_exists then 
+                -- start by adding the new value, otherwise ttl might go wrong when removing causes the set to be empty (i.e. it removes it)
+                -- note that the new profile key needs to be different from all old profile keys
+                redis.call('SADD', KEYS[1], ARGV[2])
+                redis.call('SREM', KEYS[1], unpack(old_profile_keys))
+            else
+                redis.call('SADD', KEYS[1], ARGV[2])
+                redis.call('EXPIRE', KEYS[1], {user_ttl_with_margin})
+            end
+        '''.format(user_ttl_with_margin=user_ttl + user_ttl_margin)
+
+    @classmethod
+    def finalize_profile(cls, local):
+        '''
+        KEYS[1]: profile_key
+        '''
+
+        return '''
+            local user_hash_key = redis.call('HGET', KEYS[1], '_user_hash')
+
+            if user_hash_key == false or user_hash_key == nil then
+                return nil
+            end
+
+            local current_active_profile = "0"
+
+            if redis.call('GET', user_hash_key) == KEYS[1] then
+
+                if "{local}" == "1" then
+                    redis.call('SET', user_hash_key, "none", 'EX', 110)
+                else
+                    redis.call('SET', user_hash_key, "none", 'KEEPTTL')
+                end
+                current_active_profile = "1"
+            end
+
+            local profile = {{}}
+            table.insert(profile, user_hash_key)
+            table.insert(profile, current_active_profile)
+            table.insert(profile, redis.call('HGETALL', KEYS[1]))
+
+            return profile                
+        '''.format(local=local)
+
+    @classmethod
+    def delete_in_cache(cls):
+        '''
+        KEYS[1]: profile_key
+        KEYS[2]: all profile keys key
+        '''
+
+        return '''
+            redis.call('ZREM', KEYS[2], KEYS[1])
+            redis.call('DEL', KEYS[1])
+        '''
+
+    @classmethod
+    def get_all_user_pointers_if_main_profile(cls):
+        '''
+        KEYS[1]: user pointer set key
+        ARGV[1]: user id
+        '''
+
+        return '''
+                local all_user_pointers = redis.call('SMEMBERS', KEYS[1])
+                local result = {}
+                for idx, el in pairs(all_user_pointers) do
+                    local pointed_user_id = redis.call('GET', el)
+                    if pointed_user_id == nil or pointed_user_id~=ARGV[1] then
+                        redis.call('SREM', KEYS[1], el)
+                    else
+                        table.insert(result, el)
+                    end
+                end
                 return result
             '''
\ No newline at end of file
